contrib

package module
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2024 License: BSD-3-Clause Imports: 1 Imported by: 0

README

Flogo Contrib

Build Status

Core collection of Flogo contributions. This repository consists of activities, triggers and functions.

Contributions

Activities
Triggers
Functions

Installation

Install Activity

Example: install log activity

flogo install github.com/AiRISTAFlowInc/FSContrib/activity/log
Install Trigger

Example: install rest trigger

flogo install github.com/AiRISTAFlowInc/FSContrib/trigger/rest
Install Functions

Example: install string functions

flogo install github.com/AiRISTAFlowInc/FSContrib/function/string

Contributing and support

Contributing

New activities, triggers and functions are welcomed. If you would like to contribute, please following the contribution guidelines. If you have any questions, issues, etc feel free to chat with us on Gitter.

License

The contrib repository is licensed under a BSD-type license. See LICENSE for license text.

Support

For Q&A you can post your questions on Gitter

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Version

func Version() string

Version will return the release version

Types

This section is empty.

Directories

Path Synopsis
activity
log module
trigger
rest module
timer module

Jump to